OC.L10N.register(
    "notes",
    {
    "Notes" : "Note",
    "Reading notes from filesystem has failed." : "La lettura delle note dal filesystem non è riuscita.",
    "Error" : "Errore",
    "New note" : "Nuova nota",
    "Distraction-free notes and writing" : "Note senza distrazioni e scrittura",
    "Please see Nextcloud server log for details." : "Vedi i log del server Nextcloud per i dettagli.",
    "Deleted {title}" : "Eliminato {title}",
    "Undo Delete" : "Annulla eliminazione",
    "Note recovered" : "Nota ripristinata",
    "There are unsaved notes. Leaving the page will discard all changes!" : "Ci sono note non salvate. Uscita. Se lasci la pagina perderai tutte le modifiche!",
    "_Deleted {number} note_::_Deleted {number} notes_" : ["Eliminata {number} nota","Eliminate {number} note","Eliminate {number} note"],
    "_Recovered {number} note_::_Recovered {number} notes_" : ["Ripristinata {number} nota","Ripristinate {number} note","Ripristinate {number} note"],
    "Basics" : "Nozioni di base",
    "Write down your thoughts without any distractions." : "Annota i tuoi pensieri senza alcuna distrazione.",
    "Organize your notes in categories." : "Organizza le tue note in categorie.",
    "Folder to store your notes" : "Cartella in cui memorizzare le tue note",
    "Root directory" : "Cartella principale",
    "File extension for new notes" : "Estensione dei file per le nuove note",
    "Display mode for notes" : "Modalità di visualizzazione delle note",
    "Shortcuts" : "Scorciatoie",
    "Shortcut" : "Scorciatoia",
    "Action" : "Azione",
    "User defined" : "Utente definito",
    "Open in edit mode" : "Apri in modalità modifica",
    "Open in preview mode" : "Apri in modalità anteprima",
    "CTRL" : "CTRL",
    "ALT" : "ALT",
    "SHIFT" : "SPOSTARE",
    "Insert image" : "Inserisci immagine",
    "All notes" : "Tutte le note",
    "Categories" : "Categorie",
    "No notes yet" : "Ancora nessuna nota",
    "Upload image" : "Carica immagine",
    "Select an image" : "Seleziona un'immagine",
    "You cannot select images outside of your notes folder. Your notes folder is: {folder}" : "Non è possibile selezionare immagini al di fuori della cartella delle note. La tua cartella delle note è: {folder}",
    "Wrong image" : "Immagine errata",
    "The file was not uploaded. Check your server logs." : "Il file non è stato caricato. Controlla i log del tuo server.",
    "Install the app for your mobile phone in order to access your notes from everywhere." : "Installa l'applicazione per il tuo cellulare per accedere alle tue note da ovunque.",
    "Share" : "Condivisione",
    "Delete note" : "Elimina nota",
    "Remove from favorites" : "Rimuovi dai preferiti",
    "Add to favorites" : "Aggiungi ai preferiti",
    "Error during preparing note for deletion." : "Errore durante l'eliminazione della nota.",
    "The note has been changed in another session. Please choose which version should be saved." : "La nota è stata modificata in un'altra sessione. Scegli quale versione debba essere salvata.",
    "Use version from server" : "Usa versione del server",
    "Use current version" : "Usa versione attuale",
    "Empty note" : "Nota vuota",
    "Write …" : "Scrivi...",
    "CTRL + /" : "CTRL + /",
    "Edit" : "Modifica",
    "Preview" : "Anteprima",
    "Exit full screen" : "Esci da schermo intero",
    "Full screen" : "Schermo intero",
    "Note is read-only. You cannot change it." : "La nota è in sola lettura. Non puoi cambiarla.",
    "Save failed. Click to retry." : "Salvataggio non riuscito. Fai clic per riprovare.",
    "Update conflict. Click for resolving manually." : "Conflitto di aggiornamento. Fai clic per risolvere manualmente.",
    "Error from Nextcloud server: {msg}" : "Errore dal server di Nextcloud: {msg}",
    "Loading …" : "Caricamento...",
    "Today" : "Oggi",
    "Yesterday" : "Ieri",
    "This week" : "Questa settimana",
    "Last week" : "Settimana scorsa",
    "This month" : "Questo mese",
    "Last month" : "Mese scorso",
    "Use Markdown markups to style your text." : "Usa contrassegni Markdown per formattare il tuo testo.",
    "Start writing a note by clicking on “{newnote}” in the app navigation." : "Inizia a scrivere una nota facendo clic su \"{newnote}\" nell'applicazione.",
    "Note not found." : "Nota non trovata.",
    "Note is locked." : "La nota è bloccata.",
    "Insufficient storage." : "Spazio di archiviazione insufficiente.",
    "See JavaScript console and server log for details." : "Vedi la console JavaScript e i log del server per i dettagli.",
    "Updating settings has failed." : "Aggiornamento delle impostazioni non riuscito.",
    "Fetching notes for dashboard has failed." : "Recupero delle note per il cruscotto non riuscito.",
    "Fetching notes has failed." : "Recupero delle note non riuscito.",
    "Fetching note {id} has failed." : "Recupero della nota {id} non riuscito.",
    "Refreshing note {id} has failed." : "L'aggiornamento della nota {id} non è riuscito.",
    "Renaming note {id} has failed." : "La rinomina della nota {id} non è riuscita.",
    "Creating new note has failed." : "Creazione nuova nota non riuscita.",
    "Saving note {id} has failed." : "Il salvataggio della nota {id} non è riuscito.",
    "Updating title for note {id} has failed." : "L'aggiornamento del titolo per la nota {id} non è riuscito.",
    "Undo delete has failed for note {title}." : "Annullamento eliminazione non riuscito per la nota {title}.",
    "Deleting note {id} has failed." : "Eliminazione della nota {id} non riuscita.",
    "Toggling favorite for note {id} has failed." : "L'attivazione come preferito della nota {id} non è riuscita",
    "Updating the note's category has failed. Is the target directory writable?" : "L'aggiornamento della categoria delle note non è riuscito. La cartella di destinazione è scrivibile?",
    "Updating the category for note {id} has failed." : "Aggiornamento della categoria per la nota {id} non riuscito.",
    "Uncategorized" : "Senza categoria",
    "Tasks" : "Compiti",
    "Birthdays" : "Compleanni",
    "Quotes" : "Preventivi",
    "Development Mode" : "Modalità di sviluppo",
    "It looks that the notes app was installed from a development source. Please install it from the official <a href=\"%1$s\">Nextcloud App Store</a> instead. If you want to build the Notes app by yourself, please follow the <a href=\"%2$s\">developer instructions</a>." : "Sembra che l'applicazione delle note sia stata installata da una sorgente di sviluppo. Installala invece dal <a href=\"%1$s\">Negozio delle applicazioni di Nextcloud</a> ufficiale. Se desideri compilare l'applicazione Note in autonomia, segui le <a href=\"%2$s\">istruzioni per sviluppatori</a>"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
